@@ -1,7 +1,7 @@
 #!/bin/sh
 # Test cp --reflink=auto
 
-# Copyright (C) 2009-2017 Free Software Foundation, Inc.
+# Copyright (C) 2009-2018 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,4 +38,8 @@ test -s b || fail=1
 cp --reflink=auto --sparse=always "$a_other" b || fail=1
 test -s b || fail=1
 
+# --reflink=auto should be overridden by --reflink=never
+cp --reflink=auto --reflink=never "$a_other" b || fail=1
+test -s b || fail=1
+
 Exit $fail
